@@ -1,8 +1,8 @@
-import sys
-import os
+# import sys
+# import os
 
-SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))
-sys.path.append(os.path.join(os.path.dirname(SCRIPT_DIR), "mlog++"))
+# SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))
+# sys.path.append(os.path.join(os.path.dirname(SCRIPT_DIR), "mlog++"))
 
 from lexer import Lexer
 from parser_ import Parser
